*This do files prepares the dashboard tracking fieldwork

if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}
set more off

********************************************************************************
*Setup main interview data table
********************************************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset == 2
gen interview_count=1
*keep only relevant variables
keep ParentId1 Action valid valid_reason state ea tablet_account enum_team mod_opt module? beh_treat_opt beh? athome adult maycontinue date duration datetime_b month replacement_ea interview_count dow wBegin nonmissing
order   Action valid valid_reason nonmissing state ea tablet_account enum_team mod_opt module? beh_treat_opt beh? athome adult maycontinue date duration datetime_b month replacement_ea interview_count dow wBegin ParentId1 
save "${gsdTemp}/hh_dashboard_HFSSSW4.dta", replace
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetmodify sheet("Output - Interviews") first(varl) cell(A1)

********************************************************************************
*Cumulative counts
********************************************************************************
*Whole project
use "${gsdTemp}/hh_dashboard_HFSSSW4.dta", clear
keep if valid==1
collapse (sum) interview_count, by(wBegin)
format wBegin %td
tsset wBegin, delta(7)
tsfill, full
gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var wBegin "Week of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"
format wBegin %td
*Export to dashboard excel file; modify only that tab
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetmodify sheet("Graph 9 - Interv Whole Project") first(varl) cell(A1)

*By enumerator
use "${gsdTemp}/hh_dashboard_HFSSSW4.dta", clear
keep if valid==1
collapse (sum) interview_count, by(enum_team date)
sort enum_team date
*Convert enumerator identity into a number to allow for timeseries operations; generate cumulative counts
encode enum_team, gen(xenum_team)
drop enum_team
rename xenum_team enum_team
order enum_team
tsset enum_team date
tsfill, full
by enum_team: gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var enum_team "Enumerator"
la var date "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"
*Export to dashboard excel file; modify only that tab
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetmodify sheet("Output - Enumerator II") first(varl) cell(A1)

*By team
use "${gsdTemp}/hh_dashboard_HFSSSW4.dta", clear
keep if valid==1
order state date interview_count
collapse (sum) interview_count , by(state date)
sort state date
tsset state date
tsfill, full
by state: gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var state "Team (state)"
la var date "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of interviews completed - Cumulative"
*Export to dashboard excel file; modify only that tab
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetmodify sheet("Output - Team II") first(varl) cell(A1)

**********************************
*Percent items consumed
**********************************
*Calculate number of items consumed and nonmissing consumed quantities for each module and collapse these counts by interview using parent_key.
use "${gsdTemp}/food_combined_HFSSSW4.dta", clear
forvalues i = 0/4 {
	gen mod`i'_cons=.
	replace mod`i'_cons=1 if mod_opt==`i' & rf_relevanceyn==1
}
forvalues i = 0/4 {
	gen rf_cons_quant_nonmiss`i'=.
	replace rf_cons_quant_nonmiss`i'=1 if mod_opt==`i' & rf_relevanceyn==1 & !missing(rf_cons_quant)
}
collapse (sum) rf_relevanceyn rf_cons_quant_nonmiss? mod?_cons, by(ParentId1)
rename rf_relevanceyn cons_quant_items
*Calculate percentage of items consumed out of total items on each list.
gen pct_cons_mod0=mod0_cons/33
gen pct_cons_mod1=mod1_cons/27
gen pct_cons_mod2=mod2_cons/26
gen pct_cons_mod3=mod3_cons/26
gen pct_cons_mod4=mod4_cons/28
egen pct_cons_optional=rowmax(pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4)
gen pct_cons_core=pct_cons_mod0
*calculate percentage of nonmissing quantities
gen pct_nonmiss=(rf_cons_quant_nonmiss0+rf_cons_quant_nonmiss1+rf_cons_quant_nonmiss2+rf_cons_quant_nonmiss3+rf_cons_quant_nonmiss4)/cons_quant_items
forvalues i = 0/4 {
	gen pct_nonmiss_mod`i'=rf_cons_quant_nonmiss`i'/mod`i'_cons
}
egen pct_nonmiss_optional=rowmax(pct_nonmiss_mod1 pct_nonmiss_mod2 pct_nonmiss_mod3 pct_nonmiss_mod4)
gen pct_nonmiss_core=pct_nonmiss_mod0
*cleanup and save
keep ParentId1 cons_quant_items pct_cons_core pct_cons_optional pct_nonmiss pct_nonmiss_core pct_nonmiss_optional
rename * food_*
rename food_ParentId1 ParentId1
save "${gsdTemp}/dashboard_food_collapse_HFSSSW4", replace

*nonfood
use "${gsdTemp}/nonfood_HFSSSW4.dta", clear 
*Calculate number of items consumed for each module and collapse these counts by interview using the interview Id.
forvalues i = 0/4 {
	gen mod`i'_cons=.
	replace mod`i'_cons=1 if mod_opt==`i' & rnf_relevanceyn==1
}
collapse (sum) rnf_relevanceyn mod?_cons, by(ParentId1)
rename rnf_relevanceyn cons_quant_items
*Calculate percentage of items consumed out of total items on each list.
gen pct_cons_mod0=mod0_cons/26
gen pct_cons_mod1=mod1_cons/22
gen pct_cons_mod2=mod2_cons/21
gen pct_cons_mod3=mod3_cons/18
gen pct_cons_mod4=mod4_cons/25
egen pct_cons_optional=rowmax(pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4)
gen pct_cons_core=pct_cons_mod0
*Save the food percentage scores for each interview. To be merged back in later.
keep ParentId1 cons_quant_items pct_cons_optional pct_cons_core
rename * nonfood_*
rename nonfood_ParentId1 ParentId1
save "${gsdTemp}/dashboard_nonfood_collapse_HFSSSW4.dta", replace

******************************************************
*Indicators by team
******************************************************
*Use interview table with merged food item scores
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset == 2
merge 1:1 ParentId1 using "${gsdTemp}/dashboard_food_collapse_HFSSSW4.dta", assert(match using) keep(match) nogen
merge 1:1 ParentId1 using "${gsdTemp}/dashboard_nonfood_collapse_HFSSSW4.dta", assert(match using) keep(match) nogen
keep if valid==1
gen interview_count=1
*generate no foodcons indicator
gen nofood=(food_cons_quant_items==0)
gen nononfood=(nonfood_cons_quant_items==0)
bys ea: gen new_ea=1 if _n==1
*Collapse all relevant indicators by state (team) and sort by state
collapse (sum) interview_count number_of_EAs=new_ea replacement_ea module? nofood nononfood (mean) food_* nonfood_* (p50) duration (min) first_date = date (max) last_date = date , by(state)
sort state
*Label variables for output and add state labels
la var state "State (team)"
la var interview_count "Number of interviews completed"
la var number_of_EAs "Number of EAs visited"
la var replacement_ea "Number of replacement EAs visited"
la var module1 "Number of interviews with treatment 1"
la var module2 "Number of interviews with treatment 2"
la var module3 "Number of interviews with treatment 3"
la var module4 "Number of interviews with treatment 4"
la var first_date "Earliest interview date"
la var last_date "Latest interview date"
la var duration "Median interview time in minutes"
la var food_cons_quant_items "Mean number of food items consumed"
la var food_pct_cons_core "Mean % food items consumed from core module"
la var food_pct_cons_optional "Mean % food items consumed from optional module"
la var food_pct_nonmiss_core "Mean % food items with nonmissing quantities from core module"
la var food_pct_nonmiss_optional "Mean % food items with nonmissing quantities from optional module"
la var food_pct_nonmiss "Mean % food items with nonmissing quantities"
la var nonfood_cons_quant_items "Mean number of nonfood items consumed"
la var nonfood_pct_cons_core "Mean % nonfood items consumed from core module"
la var nonfood_pct_cons_optional "Mean % nonfood items consumed from optional module"
la var duration "median interview time"
*Export to dashboard excel file; modify only that tab
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetmodify sheet("Output - Team I") first(varl) cell(A1)

******************************************************
*Indicators by enumerators
******************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset == 2
merge 1:1 ParentId1 using "${gsdTemp}/dashboard_food_collapse_HFSSSW4.dta", assert(match using) keep(match) nogen
merge 1:1 ParentId1 using "${gsdTemp}/dashboard_nonfood_collapse_HFSSSW4.dta", assert(match using) keep(match) nogen
keep if valid==1
gen interview_count=1
*generate no foodcons indicator
gen nofood=(food_cons_quant_items==0)
gen nononfood=(nonfood_cons_quant_items==0)
*Collapse all relevant indicators by enumerator and sort by enumerator
collapse (sum) interview_count nofood nononfood (mean) food_* nonfood_* (p50) duration (min) first_date = date (max) last_date = date , by(enum_team state)
sort enum_team
*Label variables for output and add state labels
la var enum_team "Enumerator"
la var interview_count "Number of interviews completed"
la var first_date "Earliest interview date"
la var last_date "Latest interview date"
la var duration "Median interview time in minutes"
la var food_cons_quant_items "Number of food items consumed"
la var food_pct_cons_core "Mean % food items consumed from core module"
la var food_pct_cons_optional "Mean % food items consumed from optional module"
la var food_pct_nonmiss_core "Mean % food items with nonmissing quantities from core module"
la var food_pct_nonmiss_optional "Mean % food items with nonmissing quantities from optional module"
la var food_pct_nonmiss "Mean % food items with nonmissing quantities"
la var nonfood_cons_quant_items "Number of nonfood items consumed"
la var nonfood_pct_cons_core "Mean % nonfood items consumed from core module"
la var nonfood_pct_cons_optional "Mean % nonfood items consumed from optional module"
la var duration "median interview time"
*Export to dashboard excel file; modify only that tab
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetmodify sheet("Output - Enumerator I") first(varl) cell(A1)

******************************************************
*Indicators by EA
******************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if valid==1 & dataset == 2
merge m:1 ea using "${gsdData}/0-RawTemp/sample_w4_ea.dta", assert(match master using) nogen
gen interview_count=1
collapse (min) first_date = date (max) last_date = date (sum) interview_count , by(ea State County Payam Boma EA replacement)
keep if !missing(first_date) | !missing(last_date)
gen complete = 0
replace complete = 1 if interview_count >= 12 & !missing(interview_count)
gen incomplete = 0
replace incomplete = 1 if interview_count < 12
label var interview_count "Number of interviews"
label var ea "EA code"
label var first_date "Date of first interview"
label var last_date "Date of last interview"
format ea %12.0f 
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetreplace sheet("Output - Incomplete Enumeration") first(varl)

******************************************************
*Check how many hh members match from panel
******************************************************
use "${gsdDownloads}/HFSSSW4/hh_list_s_presence.dta", clear
rename Id member_id
replace hh_list_s_yn=.z if hh_list_s_yn<0
collapse (sum) hh_list_s_yn (max) num_members=member_id , by(ParentId1)
merge 1:1 ParentId1 using "${gsdTemp}/hh_raw.dta", keepusing(dataset hhh_name_yn enum_clean date datetime state ea ParentId1 hhh_name_s hh_list_* athome valid) assert(match using master) keep(match using) nogen 
keep if valid==1
keep if dataset==2
replace num_members=0 if missing(num_members)
gen others_identified=hh_list_s_yn/num_members
label var others_identified "Percent hh members identified, not hh head"
label var hhh_name_yn "Previous hh head lives in hh"
label var hh_list_s_yn "No. of previous (adult) hh members still living in hh"
label var num_members "Number of previous (adult) hh members"
gen issue=(hhh_name_yn!=1 & (others_identified==0 | missing(others_identified)))
keep if issue==1
rename hh_list_s__* hh_previous_wave*
foreach v of varlist hh_previous_* {
	label var `v' "HH members from previous wave"
	replace `v'="" if `v'=="N/A"
}
rename hh_list__* hh_members*
foreach v of varlist hh_members* {
	label var `v' "HH members listed"
	replace `v'="" if `v'=="N/A"
}
rename hh_list_separated_* hh_separated*
foreach v of varlist hh_separated* {
	label var `v' "HH members separated listed"
	replace `v'="" if `v'=="N/A"
}
ds3, all(missing(X))
drop athome `r(varlist)'  
order hhh_name_yn others_identified num_members hh* enum_clean date datetime state ea ParentId1
sort state ea
if _N<1 {
	set obs 1
	gen x=1
}
export excel using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetreplace sheet("Problematic household matches") first(varl)

******************************************************
*Check if there are systematic missing variables (requires cleaning up the folder beforehand)
******************************************************
/* Checked once and there are none 
local files : dir "${gsdDownloads}/HFSSSW4" files "*.dta"
foreach f of local files { 
	use "${gsdDownloads}/HFSSSW4/`f'", clear
	display "`f'" 
	ds3, all(missing(X)) d
}
*/

**************************************************************************************
*Report observations that do not appear to be close to their assigned geo-coordinates.
*************************************************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if valid == 1 & dataset == 2
run "${gsdDo}/fdistance.do"
quietly fDistance gps__Latitude gps__Longitude loc__Latitude loc__Longitude dist
keep if dist > 50 & !missing(dist)

*********************************************************************
*Report interviews without household head and household respondent
*********************************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset == 2
replace valid=(athome==1 & adult==1 & maycontinue==1 )
label var valid "Valid except for hhh and hhr"
gen missing_hhh =  missing(hhh_id) 
label var missing_hhh "Missing hh head"
gen missing_hhr = missing(hhr_id)
label var missing_hhr "Missing hh respondent"
label var missing_hhroster "Missing hh roster"
keep if (missing_hhh == 1 | missing_hhr == 1 | missing_hhroster==1)
keep enum_clean date datetime state ea ParentId1 missing_hhh missing_hhr missing_hhroster hh_list__*
order enum_clean date datetime state ea ParentId1 missing_hhh missing_hhr missing_hhroster hh_list__*
if _N<1 {
	set obs 1
	gen x=1
}
export excel  using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetreplace sheet("Missing hhh, hhr, or hh roster") first(varl)

/*
*********************************************************************
*Report interviews with missing validity conditions (Athome etc.)
*********************************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==2
keep if valid==0
drop if !missing(athome) & !missing(adult) & !missing(maycontinue)
drop if athome==0 | adult==0 | maycontinue==0
keep ParentId1 Action valid state ea tablet_account enum_team athome adult maycontinue datetime_b nonmissing
export excel  using "${gsdOutput}/Dashboard_HFSSSW4.xlsx", sheetreplace sheet("Issues with validity conditions") first(varl)



