*this do file prepares the hh dataset from the CRS and HFSSSW4 main data files

if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}
set more off

*prepare list of EAs in sample
*CRS
import excel "${gsdDataRaw}/Sample_IDP.xlsx", sheet("Master") firstrow clear
*sometimes replace is greater than 1 so replace it wiht 1
replace replace=1 if replace>1 & !missing(replace)
keep if selected == 1 | replace==1
keep ea selected replace
destring ea , replace 
format ea %12.0f
save "${gsdData}/0-RawTemp/sample_IDP.dta", replace
*HFSSSW4
import excel "${gsdDataRaw}/Sample_W4_EA.xlsx", sheet("Master") firstrow clear
split s_ea_full , parse(,)
rename (s_ea_full1 s_ea_full2 s_ea_full3 s_ea_full4 s_ea_full5 s_v replacement_ea) (State County Payam Boma EA state replacement)
replace EA = subinstr(EA," (Urban)","",.)
labmask state , values(State)
destring ea , replace 
format ea %12.0f
order state ea State County Boma Payam EA replacement gps*
save "${gsdData}/0-RawTemp/sample_w4_ea.dta", replace

*Generate interview time and interview status from the interview_actions data
local datasets = "${available}" 
foreach d of local datasets {
	use "${gsdDownloads}/`d'/interview_actions.dta", clear
	format * %32s
	*keep only the first FirstAnswerSet and the first Completed
	sort InterviewId Date Time
	keep if Action=="Completed" | Action=="FirstAnswerSet" 
	duplicates drop InterviewId Action Originator , force
	*generate date variables and calculate the duration of the interview
	gen DateTime=Date + " " + Time
	gen double datetime_c=Clock(DateTime, "MDYhms")
	format datetime_c %tC
	gen date_alt=dofC(datetime_c)
	format date_alt %td
	gen time= hhC(datetime_c) + mmC(datetime_c)/60 + ssC(datetime_c)/3600
	gen duration_alt = time-time[_n-1] if (Originator==Originator[_n-1] & date_alt==date_alt[_n-1])
	*keep relevant variables and save
	keep if Action=="Completed" | Action=="ApprovedBySupervisor" 
	keep InterviewId Originator datetime_c date_alt duration_alt
	rename (InterviewId Originator ) (Id tablet_account )
	save "${gsdTemp}/interview_times_`d'.dta", replace
	
	use "${gsdDownloads}/`d'/interview_actions.dta", clear
	format * %32s	
	sort InterviewId Date Time
	rename InterviewId Id
	collapse (last) Action, by(Id)
	label var Action "Status of interview"
	save "${gsdData}/0-RawTemp/interview_status_`d'.dta", replace	
}


*Clean CRS data for merge
use "${gsdDownloads}/CRS/${CRS}.dta" , clear
*make manual corrections
do "${gsdDo}/0-2-1-Corrections_CRS.do"
*keep interviews that have been approved, remove rejected interviews
merge 1:1 Id using "${gsdData}/0-RawTemp/interview_status_CRS.dta", assert(match using) keep(match using) nogen
*merge with interview duration data, only completed interviews will be matched so drop the incomplete ones
merge 1:1 Id using "${gsdTemp}/interview_times_CRS.dta" , assert(match using) nogen keep(match)
*create team variable
format ea_block %12.0f
gen camp = team_ea
labmask camp, val(team_ea) decode
*create ea variable
gen ea=qr_id_ea if qr_id_ea!=""
tostring ea_idp, replace force
replace ea=ea_idp if ea=="." & ea_idp!="."
replace ea="" if ea=="."
destring ea, replace
*check all eas are in the correct camp
assert camp==round(ea/1000) if !missing(ea) & camp!=1
*Juba POC1 and 3 EAs are coded starting with 1 and 3, but camp code is always 1
assert round(ea/1000)==1 | round(ea/1000)==3  if !missing(ea) & camp==1
*tag observations with missing EAs, they are all empty interviews that are dropped later during validity checks
gen missing_ea=(missing(ea))
label var missing_ea "EA code is missing"
*clean up enumerator identities
gen enum_clean=qr_id if qr_idcheck != 0
order enum_clean , before(qr_id)
decode enum_id_idp , gen(xenum_clean)
replace enum_clean=xenum_clean if enum_check != 0 & missing(enum_clean)
replace enum_clean = name_idp if missing(enum_clean) & !missing(name_idp)
decode camp, gen(team)
drop x*
gen enum_team = enum_clean + " from Team " + team
*create one dummy variable for each module
gen mod_opt = mod(ea_block,4) +1 
tab mod_opt , gen(module)
gen beh_treat_opt = mod(ea_block,2)
tab beh_treat_opt, gen(beh)
label define lbeh 0 "Control" 1 "Treatment"
label variable beh_treat_opt "Treatment for behavioral nudges"
*Preparing for Append:
tostring *_ot *_spec *_sp disp_temp_return_reason_s, replace
save "${gsdTemp}/hh_CRS_forappend.dta", replace

*Clean HFSSSW4 data for merge
use "${gsdDownloads}/HFSSSW4/${HFSSSW4}.dta" , clear
*make manual corrections
do "${gsdDo}/0-2-2-Corrections_HFS.do"
*keep interviews that have been approved, remove rejected interviews
merge 1:1 Id using "${gsdData}/0-RawTemp/interview_status_HFSSSW4.dta", assert(match using) keep(match ) nogen
drop if inlist(Action,"InterviewerAssigned")
*merge with interview duration data, only completed interviews will be matched so drop the incomplete ones
merge 1:1 Id using "${gsdTemp}/interview_times_HFSSSW4.dta" , assert(match using) nogen keep(match)
*clean up enumerator identities
decode s_v, gen(xs_v)
gen enum_clean=qr_id if qr_id!="##N/A##"
replace enum_clean=subinstr(enum_clean,"_"," ",.)
decode enum_id , gen(xenum_clean)
*remove one qr scan code bug
replace enum_clean=xenum_clean if enum_clean=="" | enum_clean=="]e00108904244596768"
replace enum_clean=name if enum_clean=="" & name!=""
replace enum_clean="unknown" if enum_clean=="" | enum_clean=="##N/A##"
replace enum_clea=subinstr(enum_clean,xs_v,"",.)
replace enum_clean=subinstr(enum_clean," from Team ","",.)
gen enum_team=enum_clean+ " from Team " + xs_v
drop x*
*create one dummy variable for each module
tab mod_opt , gen(module)
tab beh_treat_opt, gen(beh)
tostring *_ot *_spec *_sp disp_temp_return_reason_s, replace
save "${gsdTemp}/hh_HFSSSW4_forappend.dta", replace

*Append
use "${gsdTemp}/hh_CRS_forappend.dta", clear
gen dataset = 1
append using "${gsdTemp}\hh_HFSSSW4_forappend.dta"
replace dataset = 2 if missing(dataset)
label define dataset 1 "CRS" 2 "HFS"
label val dataset dataset
label var dataset "Dataset"

*Clean appended dataset
***chech for valid interviews
*clean not applicables saved as missing
ds, has (type numeric)
foreach v in `r(varlist)' {
	replace `v' = .z if `v'== .
}
*clean missings saved as -999999999
ds , has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = . if `v'==-999999999
}
ds, has (type string)
foreach v in `r(varlist)' {
	replace `v' = "N/A" if `v'==""
	replace `v' = "##N/A##" if `v'== ""
}
*rename Id to ease merging with other datasets
ren Id ParentId1
*check for existence of household roster
merge 1:1 ParentId1 using "${gsdData}/0-RawTemp/hhsize.dta" , assert(match master using) keep(match master) nogen
gen missing_hhroster=missing(hhsize)
*Identify member Id for household head:
gen hhh_id = hhh_id0 if hhh_presence != 0 
replace hhh_id = hhh_id1 if hhh_presence == 0
*replace hhh_id if hhh only ate meals elsewhere but was present at the household otherwise
replace hhh_id=hhh_id0 if hhh_absence_reason==0
*replace hhh_id if hhh was gone for meals but there is no other alternative hhh (7 cases in CRS)
replace hhh_id=hhh_id0 if hhh_presence==0 & missing(hhh_id1)
order hhh_id, before(hhh_id0)
*generate valid interviews tag
gen valid=(athome==1 & adult==1 & maycontinue==1 & type==1 & !missing(hhh_id) & !missing(hhr_id) & missing_hhroster==0 )
*replace valid=0 if inlist(Action,"RejectedBySupervisor","RejectedByHeadquarter")
label var valid "Valid interview"
label define lvalid 0 "No" 1 "Yes"
label val valid lvalid
*check for number of answers
egen nonmissing=rownonmiss(*),strok
label var nonmissing "Number of nonmissing variables"
*make invalid interviews with less than 100 nonmissing values that are otherwise valid
gen empty_interview=1 if nonmissing<100 & valid==1
*replace valid=0 if empty_interview==1 
*generate reason invalid variable
gen valid_reason=0
label define valid_reason 0 "Valid"
label val valid_reason valid_reason
replace valid_reason=1 if missing_hhroster==1 & nonmissing>100
label define valid_reason 1 "Missing hh roster", modify
replace valid_reason=2 if missing(hhh_id) & nonmissing>100
label define valid_reason 2 "Missing hh head id", modify
replace valid_reason=3 if missing(hhr_id) & nonmissing>100
label define valid_reason 3 "Missing hh resp. id", modify
replace valid_reason=4 if (athome!=1 | adult !=1 | maycontinue!=1) 
label define valid_reason 4 "No in athome, adult, maycontinue", modify
*replace valid_reason=5 if inlist(Action,"RejectedBySupervisor","RejectedByHeadquarter")
*label define valid_reason 5 "Rejected by Forcier", modify
replace valid_reason=6 if nonmissing<100 & empty_interview==1
label define valid_reason 6 "Too few answers", modify
*drop CRS interviews with too few answers (the number if lower because of prefilled variables in HFS)
drop if nonmissing<40 & dataset==1
*drop HFS interviews with too few answers
drop if nonmissing<150 & dataset==2
*remove invalid interviews
tab valid dataset
drop if valid==0

***dates and interview duration
*create alternative interview duration measure
gen datetime_b=Clock(today,"YMD#hms#")
format datetime_b %tC
local mod = "A_A B C D E F G H I J K"
foreach m of local mod {
	replace datetime_b=Clock(today`m'_b,"YMD#hms#") if datetime_b==. 
}
gen datetime_e=Clock(todayK_e,"YMD#hms#")
format datetime_e %tC
local mod = "K J I H G F E D C B A_A"
foreach m of local mod {
	replace datetime_e=Clock(today`m'_e,"YMD#hms#") if datetime_e==. 
}
label var datetime_b "Beginning of interview"
label var datetime_e "End of interview"
gen duration=(datetime_e-datetime_b)/(1000*60*60)
replace duration=duration_alt if duration<0
replace duration=duration_alt if duration>6
replace duration=. if duration>6
*create date variables (make sure there are no missing variables, and if so use the other available dates)
gen date=dofC(datetime_e)
replace date=dofC(datetime_c) if missing(date)
replace date=dofC(datetime_b) if missing(date)
replace date=date_alt if missing(date)
assert !missing(date)
*create datetime variable
gen datetime=datetime_b 
replace datetime=datetime_e if missing(datetime)
replace datetime=datetime_c if missing(datetime)
assert !missing(datetime)
format datetime %tC
*replace too old dates (sometimes the tablets have date issues) and add month
replace date=. if date<td(01012017)
format date %td
gen dow=dow(date)
gen wBegin = date-dow
gen str3 month=""
replace month="Jan" if month(date)==1
replace month="Feb" if month(date)==2
replace month="Mar" if month(date)==3
replace month="Apr" if month(date)==4
replace month="May" if month(date)==5
replace month="Jun" if month(date)==6
replace month="Jul" if month(date)==7
replace month="Aug" if month(date)==8
replace month="Sep" if month(date)==9
replace month="Oct" if month(date)==10
replace month="Nov" if month(date)==11
replace month="Dec" if month(date)==12
**Consolidating geo_location
replace loc__Latitude = loc_end__Latitude if missing(loc__Latitude)
replace loc__Longitude = loc_end__Longitude if missing(loc__Longitude)
replace loc__Accuracy = loc_end__Accuracy if missing(loc__Accuracy)
replace loc__Altitude = loc_end__Altitude if missing(loc__Altitude)
replace loc__Timestamp = loc_end__Timestamp if missing(loc__Timestamp)
drop loc_end* loc_check*
*clean up and save
drop type examnumber modules__1 modules__2 modules__3 modules__4 modules__5 modules__6 modules__7 modules__8 modules__9 modules__10 modules__11 modules__12 modules__13 
drop qr_id qr_idcheck qr_noid team_id_idp enum_id_idp enum_check_idp name_idp qr_id_ea qr_id_ea_check qr_noid_ea team_ea ea_idp ea_idp_r ea_block_confirm_idp
drop ea_confirm name enum_check enum_id team_id interview__key int_num
format ea %12.0f
rename s_v state
save "${gsdTemp}/hh_raw.dta", replace
