*this do file prepares and appends the food data

if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}
set more off

**********************************
*Prepare food data
**********************************
*create fooditem labels key file
import delimited "${gsdDataRaw}/rf_food.csv", clear varnames(1)
collapse itemid , by(itemlabel mod_opt)
save "${gsdTemp}/food_itemlabels.dta", replace

*loop over the datasets
local datasets = "${available}" 
foreach d of local datasets {
	*Take relevance answers from main dataset with the food rosters.
	use "${gsdDownloads}/`d'/${`d'}.dta" , clear
	keep rf_relevance* Id
	ren rf_relevanceyn_br__* a*
	ren rf_relevanceyn_m__* a*
	ren rf_relevanceyn_f__* a*
	ren rf_relevanceyn_p__* a*
	ren rf_relevanceyn_ot__* a*
	reshape long a, i(Id) j(itemid)
	ren a rf_relevanceyn 
	replace rf_relevanceyn=. if rf_relevanceyn==-999999999
	label define lyn 0 "No" 1 "Yes"
	label val rf_relevanceyn lyn
	rename Id ParentId1
	save "${gsdTemp}/food_relevance_`d'.dta", replace
	*combine food files
	use "${gsdDownloads}/`d'/rf_food.dta", clear
	local files = "br f m p"
	foreach f of local files {
		append using "${gsdDownloads}/`d'/rf_food_`f'.dta" , nolabel
	}
	*turn mepty variables that are byte but should be strings into strings
	ds *_other* *_sp*,
	foreach v in `r(varlist)' {
		local vartype : type `v'
		if "`vartype'"=="byte" {
			tostring `v' , replace
		}
	}
	*replace missing values in corresponding in base food file (no suffix) with the values from the other food files
	ds Id ParentId1  *_br *_f *_m *_p *_other* *_sp*, not
	foreach f of local files {
		foreach v in `r(varlist)' {
			di "`v'"
			replace `v' = `v'_`f' if !missing(`v'_`f')
		}
	}
	*do it now for the string variables
	ds *_other *_sp,
	foreach f of local files {
		foreach v in `r(varlist)' {
			replace `v' = `v'_`f' if `v'_`f'!=""
		}
	}	
	*merge with file containing item labels
	rename Id itemid 
	merge m:1 itemid using "${gsdTemp}/food_itemlabels.dta", assert(match) nogen
	labmask itemid ,val(itemlabel)
	drop itemlabel *_br *_f *_m *_p
	*clean missings saved as -999999999
	ds , has(type numeric)
	foreach v in `r(varlist)' {
		replace `v' = .z if `v'==-999999999
	}
	*merge with relevance file
	merge 1:1 ParentId1 itemid using "${gsdTemp}/food_relevance_`d'.dta", assert(match) nogen
	order ParentId1 itemid rf_relevanceyn
	save "${gsdTemp}/food_combined_`d'.dta", replace
}
*append
use "${gsdTemp}/food_combined_HFSSSW4.dta", clear
tostring rf_pric_total_sp, replace
append using "${gsdTemp}/food_combined_CRS.dta" 
*keep only interviews from the main dataset
merge m:1 ParentId1 using "${gsdTemp}/hh_raw.dta", nogen assert(match master) keep(match) keepusing(dataset)
save "${gsdTemp}/food_raw.dta", replace
