*This do file calcualtes weights
*this do file prepares the weights
if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}

********************************************************************************
*HFS prepare
********************************************************************************
*prepare HHinstratum data
import delimited using "${gsdDataRaw}/HHinstratum_W1.csv", varn(1) clear
keep if urbanicity=="Urban"
drop urbanicity
save "${gsdTemp}/HHinStratum.dta" , replace
*prepare file with replacement ea for weights
import excel using "${gsdDataRaw}/EA Replacements_HFSSS_v1.xlsx", clear first cellrange(F1:I11)
keep o_ea r_ea
keep if r_ea!=""
drop if length(r_ea)!=12
destring o_ea r_ea, replace
rename r_ea ea
format ea o_ea %12.0f
save "${gsdTemp}/Replacements_HFSSSW4.dta", replace

********************************************************************************
*Cross sectional weights using sample frames
********************************************************************************
*prepare the necessary data from w1 and w2 sample frames
use "${gsdDataRaw}/W2_sample_master.dta", clear
keep ea_field nhh_ea_list households
format ea_field %12.0f
rename (ea_field households nhh_ea_list) (ea households_w2 nhh_listing_w2)
order ea households_w2 nhh_listing_w2
save "${gsdTemp}/W2_hh_ea.dta", replace
import excel using "${gsdDataRaw}/W1_sample_master.xlsx", clear first sheet("Weight calculation")
keep if Urbanicity=="Urban"
destring EA, replace
format EA %12.0f
rename (EA households hhslisted) (ea households_w1 nhh_listing_w1)
keep ea households_w1 nhh_listing_w1
order ea households_w1 nhh_listing_w1
*merge with listing to get some missing nhh listed
merge 1:1 ea using "${gsdDataRaw}/W1_ea-listing.dta", nogen assert(match master using) keep(match master)
replace nhh_listing=nhhc if missing(nhh_listing)
drop nhhc
save "${gsdTemp}/W1_hh_ea.dta", replace

*merge to main data
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==2
*collapse to get interview count and EA count per state
collapse (count) nhh_ea_interviewed=maycontinue , by(state ea)
*replace ea code of replacement eas with their original ea for merging with census/listing data
merge 1:1 ea using "${gsdTemp}/Replacements_HFSSSW4.dta", keep(match master) nogen
*merge weights to ea code and original ea
rename ea actual_ea
gen double ea=actual_ea
format ea %12.0f
replace ea=o_ea if !missing(o_ea)
*merge households and listing data
merge 1:1 ea using "${gsdTemp}/W1_hh_ea.dta", nogen keep(match master) assert(match master using)
merge 1:1 ea using "${gsdTemp}/W2_hh_ea.dta", nogen keep(match master) assert(match master using)
*drop the replacement ea data
drop o_ea ea
rename actual_ea ea
*consolidate listing and number of households data
gen nhh_ea_census=households_w1
replace nhh_ea_census=households_w2 if missing(nhh_ea_census)
gen nhh_ea_listing=nhh_listing_w1
replace nhh_ea_listing=nhh_listing_w2 if missing(nhh_ea_listing)
drop *_w*
*merge number of hh per stratum
merge m:1 state using "${gsdTemp}/HHinStratum.dta", nogen assert(match master using) keep(match master) 
rename hhinstratum nhh_stratum_census
*calculate number of EAs per state
bys state: egen nea_stratum=count(ea)
*calculate weights
*P1 is the number of EAs in the stratum * (number of households in the EA / Number of households in the stratum)
gen P1=nea_stratum*(nhh_ea_census/nhh_stratum_census)
*Calculate sampling weights based on the census and based on the listing
foreach k in census listing {
	*Then calculate probability of HH selection
	gen P2_`k' = nhh_ea_interviewed / nhh_ea_`k'
	*Next calculate the weight as the inverse joint probability of HH and EA selection
	gen pweight_`k' = 1/(P1 * P2_`k')
	*Next generate sum of weights by state-stratum
	bysort state: egen tot_pweight_`k' = sum(nhh_ea_interviewed * pweight_`k')
}
gen weight = pweight_list * tot_pweight_cens / tot_pweight_list
label var weight "Population weight based on listing scaled to Census"
save "${gsdData}/0-RawTemp/weights_HFSSSW4.dta", replace

********************************************************************************
*Panel weights for households from waves 1-2-4
********************************************************************************
*merge to main data
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==2
*get parent key
merge 1:1 ParentId1 using "${gsdTemp}/hh_matchkeys.dta", nogen assert(match)
keep if sample_W1W2W4==1
*collapse to get interview count and EA count per state
collapse (count) nhh_ea_interviewed=maycontinue , by(state ea)
*replace ea code of replacement eas with their original ea for merging with census/listing data
merge 1:1 ea using "${gsdTemp}/Replacements_HFSSSW4.dta", keep(match master) nogen
*merge weights to ea code and original ea
rename ea actual_ea
gen double ea=actual_ea
format ea %12.0f
replace ea=o_ea if !missing(o_ea)
*merge households and listing data
merge 1:1 ea using "${gsdTemp}/W1_hh_ea.dta", nogen keep(match master) assert(match master using)
merge 1:1 ea using "${gsdTemp}/W2_hh_ea.dta", nogen keep(match master) assert(match master using)
*drop the replacement ea data
drop o_ea ea
rename actual_ea ea
*consolidate listing and number of households data
gen nhh_ea_census=households_w1
replace nhh_ea_census=households_w2 if missing(nhh_ea_census)
gen nhh_ea_listing=nhh_listing_w1
replace nhh_ea_listing=nhh_listing_w2 if missing(nhh_ea_listing)
drop *_w*
*merge number of hh per stratum
merge m:1 state using "${gsdTemp}/HHinStratum.dta", nogen assert(match master using) keep(match master) 
rename hhinstratum nhh_stratum_census
*calculate number of EAs per state
bys state: egen nea_stratum=count(ea)
*calculate weights
*P1 is the number of EAs in the stratum * (number of households in the EA / Number of households in the stratum)
gen P1=nea_stratum*(nhh_ea_census/nhh_stratum_census)
*Calculate sampling weights based on the census and based on the listing
foreach k in census listing {
	*Then calculate probability of HH selection
	gen P2_`k' = nhh_ea_interviewed / nhh_ea_`k'
	*Next calculate the weight as the inverse joint probability of HH and EA selection
	gen pweight_`k' = 1/(P1 * P2_`k')
	*Next generate sum of weights by state-stratum
	bysort state: egen tot_pweight_`k' = sum(nhh_ea_interviewed * pweight_`k')
}
gen weight_panel1 = pweight_list * tot_pweight_cens / tot_pweight_list
label var weight "Population weight for households interviewed in waves 1,2, and 4, based on listing scaled to Census"
save "${gsdData}/0-RawTemp/weights_panel1_HFSSSW4.dta", replace

********************************************************************************
*Panel weights for households from waves 2-4
********************************************************************************
*merge to main data
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==2
*get parent key
merge 1:1 ParentId1 using "${gsdTemp}/hh_matchkeys.dta", nogen assert(match)
keep if sample_W2W4==1
*collapse to get interview count and EA count per state
collapse (count) nhh_ea_interviewed=maycontinue , by(state ea)
*replace ea code of replacement eas with their original ea for merging with census/listing data
merge 1:1 ea using "${gsdTemp}/Replacements_HFSSSW4.dta", keep(match master) nogen
*merge weights to ea code and original ea
rename ea actual_ea
gen double ea=actual_ea
format ea %12.0f
replace ea=o_ea if !missing(o_ea)
*merge households and listing data
merge 1:1 ea using "${gsdTemp}/W1_hh_ea.dta", nogen keep(match master) assert(match master using)
merge 1:1 ea using "${gsdTemp}/W2_hh_ea.dta", nogen keep(match master) assert(match master using)
*drop the replacement ea data
drop o_ea ea
rename actual_ea ea
*consolidate listing and number of households data
gen nhh_ea_census=households_w1
replace nhh_ea_census=households_w2 if missing(nhh_ea_census)
gen nhh_ea_listing=nhh_listing_w1
replace nhh_ea_listing=nhh_listing_w2 if missing(nhh_ea_listing)
drop *_w*
*merge number of hh per stratum
merge m:1 state using "${gsdTemp}/HHinStratum.dta", nogen assert(match master using) keep(match master) 
rename hhinstratum nhh_stratum_census
*calculate number of EAs per state
bys state: egen nea_stratum=count(ea)
*calculate weights
*P1 is the number of EAs in the stratum * (number of households in the EA / Number of households in the stratum)
gen P1=nea_stratum*(nhh_ea_census/nhh_stratum_census)
*Calculate sampling weights based on the census and based on the listing
foreach k in census listing {
	*Then calculate probability of HH selection
	gen P2_`k' = nhh_ea_interviewed / nhh_ea_`k'
	*Next calculate the weight as the inverse joint probability of HH and EA selection
	gen pweight_`k' = 1/(P1 * P2_`k')
	*Next generate sum of weights by state-stratum
	bysort state: egen tot_pweight_`k' = sum(nhh_ea_interviewed * pweight_`k')
}
gen weight_panel2 = pweight_list * tot_pweight_cens / tot_pweight_list
label var weight "Population weight for households interviewed in waves 2 and 4, based on listing scaled to Census"
save "${gsdData}/0-RawTemp/weights_panel2_HFSSSW4.dta", replace

********************************************************************************
*merge and save
********************************************************************************
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==2
merge m:1 ea using "${gsdData}/0-RawTemp/weights_HFSSSW4.dta", nogen assert(match master) keepusing(weight) 
assert !missing(weight)
merge m:1 ea using "${gsdData}/0-RawTemp/weights_panel1_HFSSSW4.dta", nogen assert(match master) keepusing(weight_panel1) 
merge m:1 ea using "${gsdData}/0-RawTemp/weights_panel2_HFSSSW4.dta", nogen assert(match master) keepusing(weight_panel2) 
*set weights as missing for the households in the correct EAs but not interviewed in the proper waves
merge 1:1 ParentId1 using "${gsdTemp}/hh_matchkeys.dta", nogen assert(match)
replace weight_panel1=. if sample_W1W2W4!=1
replace weight_panel2=. if sample_W2W4!=1
*inspect
foreach w of varlist weight weight_panel1 weight_panel2 {
	bys state: egen xcheck=total(`w')
	tab xcheck
	drop xcheck
}
su weight*
drop parent_key
save "${gsdTemp}/hh_hfs_raw_withweights.dta", replace
