*this do file anonymizes the data
*Anonymize all datasets
set seed 937483836

********************************************************************************
*HFS
********************************************************************************
use "${gsdTemp}/hh_matchkeys.dta", clear
*merge with wave 2 households anonkey
merge 1:1 parent_key using "${gsdDataRaw}/hh_anonkey_W2.dta", assert(match master using) keep(match master) keepusing(hh_anon) nogen
rename (parent_key hh_anon) (hhuid hh_anon2)
merge 1:1 hhuid using "${gsdDataRaw}/hh_anonkey_W1.dta", assert(match master using) keep(match master) keepusing(hh_anon) nogen
replace hh_anon=hh_anon2 if missing(hh_anon)
drop hh_anon2
*merge ea codes
merge 1:1 ParentId1 using "${gsdTemp}/hh_raw.dta", nogen assert(match using) keep(match) keepusing(ea)
merge m:1 ea using "${gsdDataRaw}/ea_anonkey_W2.dta", assert(match master using) keep(match master) keepusing(ea_anon) nogen
rename ea_anon ea_anon2
merge m:1 ea using "${gsdDataRaw}/ea_anonkey_W1.dta", assert(match master using) keep(match master) keepusing(ea_anon) nogen
replace ea_anon=ea_anon2 if missing(ea_anon)
assert (ea_anon-ea_anon2)==round(0,0.0001) if !missing(ea_anon2)
drop ea_anon2 
*create hh id for those households taken from the listing
sort ea hh_anon
bysort ea: egen max_id=max(hh_anon)
by ea: replace hh_anon=hh_anon[_n-1]+1 if missing(hh_anon) & hh_anon[_n-1]>=max_id
drop ea max_id
save "${gsdData}/0-RawTemp/anonkey.dta", replace
*prepare enumerator anonkey
import excel using "${gsdDataRaw}/enum_id_previous.xlsx", clear first
drop enum_m
gen rand=runiform() if missing(enum_m_old)
sort rand
*begin new identities at 40 so as not to overlap with previous identities
replace enum_m_old=40+_n if missing(enum_m_old)
rename enum_m_old enum_anon
drop rand
save "${gsdData}/0-RawTemp/enum_anonkey.dta", replace
*anonymize main HFS dataset
use "${gsdTemp}/hh_hfs_raw_withweights.dta", clear
keep if dataset==2
merge 1:1 ParentId1 using "${gsdData}/0-RawTemp/anonkey.dta" , assert(match master) nogen keepusing(hh_anon ea_anon)
merge m:1 enum_clean using "${gsdData}/0-RawTemp/enum_anonkey.dta" , assert(match master) nogen
*relabel
replace ea=ea_anon if dataset==2
label var ea "EA"
gen hh=hh_anon
label var hh "Household ID"
rename enum_anon enum
label var enum "Enumerator ID"
drop ea_anon hh_anon
sort state ea hh
order state ea hh
save "${gsdTemp}/hh_hfs_anon.dta", replace

********************************************************************************
*CRS
********************************************************************************
*use "${gsdTemp}/hh_raw_withweights.dta", clear
*...






*append the two anonymized datasets
use "${gsdTemp}/hh_hfs_anon.dta", clear
*append using "${gsdTemp}/hh_crs_anon.dta"
save "${gsdData}/0-RawOutput/hh.dta", replace

********************************************************************************
*Other datasets
********************************************************************************
*Load hhm data
use "${gsdTemp}/hhm_raw.dta", clear
*Merge anonymized household IDs
merge m:1 ParentId1 using "${gsdData}/0-RawOutput/hh.dta" , assert(match master using) keep(match master) nogen keepusing(state ea hh)
order state ea hh
rename Id hhmid 
label var hhmid "Household member ID"
sort state ea hh hhmid
*Save anonymized hhm data
save "${gsdData}/0-RawOutput/hhm.dta", replace

*hhm separated data
use "${gsdTemp}/hhm_separated_raw.dta", clear
*Merge anonymized household IDs
merge m:1 ParentId1 using "${gsdData}/0-RawOutput/hh.dta" , assert(match master using) keep(match master) nogen keepusing(state ea hh)
order state ea hh
rename Id hhmid_sep 
label var hhmid_sep "Separated household member ID"
sort state ea hh hhmid_sep
*Save anonymized hhm data
save "${gsdData}/0-RawOutput/hhm_separated.dta", replace

*consumption data
foreach sf in food nonfood livestock assets {
	*Load consumption data
	use "${gsdTemp}/`sf'_raw.dta", clear
	if "`sf'"=="food" | "`sf'"=="nonfood" {
		sort ParentId1 itemid
		}
	else if "`sf'"=="livestock" {
		sort ParentId1 index
		}
	else if "`sf'"=="assets" {
		sort ParentId1 index
		}
	*Merge anonymized household IDs, don't keep households that were previously dropped
	merge m:1 ParentId1 using "${gsdTemp}/hh_hfs_anon.dta" , assert(match master using) keep(match master) nogen keepusing(state ea hh)
	*Merge state and non-anonymized EAs
	*Rename and reorder
	order state ea hh
	sort state ea hh
	*Save anonymized consumption data
	save "${gsdData}/0-RawOutput/`sf'.dta", replace
}
